#ifndef FTDI_VERSION_INTERNAL_H
#define FTDI_VERSION_INTERNAL_H

#define FTDI_MAJOR_VERSION 1
#define FTDI_MINOR_VERSION 5
#define FTDI_MICRO_VERSION 0

const char FTDI_VERSION_STRING[] = "1.5";
const char FTDI_SNAPSHOT_VERSION[] = "unknown";

#endif
